@@ -17,29 +17,31 @@
 
 #include <gnuradio/api.h>
 #include <gnuradio/thread/thread.h>
-#include <boost/function.hpp>
-#include <boost/thread/shared_mutex.hpp>
-#include <boost/utility.hpp>
+#include <shared_mutex>
+#include <functional>
+#include <memory>
 
 namespace gr {
 namespace thread {
 
-class GR_RUNTIME_API thread_group : public boost::noncopyable
+class GR_RUNTIME_API thread_group
 {
 public:
     thread_group();
     ~thread_group();
+    thread_group(const thread_group&) = delete;
+    thread_group& operator=(const thread_group&) = delete;
 
-    boost::thread* create_thread(const boost::function0<void>& threadfunc);
-    void add_thread(boost::thread* thrd);
+    boost::thread* create_thread(const std::function<void()>& threadfunc);
+    void add_thread(std::unique_ptr<boost::thread> thrd);
     void remove_thread(boost::thread* thrd);
     void join_all();
     void interrupt_all();
     size_t size() const;
 
 private:
-    std::list<boost::thread*> m_threads;
-    mutable boost::shared_mutex m_mutex;
+    std::list<std::unique_ptr<boost::thread>> m_threads;
+    mutable std::shared_mutex m_mutex;
 };
 
 } /* namespace thread */
